@@ -1,4 +1,6 @@
-library(SoPhy)
+# source("test.R")
+
+if (file.exists("source.R")) source("source.R")
 
 ## redo example 1 of SWMS_2d
 
